#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""Created on Fri Jan 05 2024 18:10:32 by codeskyblue
"""
from __future__ import annotations

import click
from dataclasses import dataclass
from pymobiledevice3.cli.cli_common import USBMUX_OPTION_HELP
from pymobiledevice3.lockdown import LockdownClient
from pymobiledevice3.lockdown import create_using_usbmux


@dataclass
class GlobalConfig:
    udid: str | None = None
    color: bool = True
    usbmux_address: str | None = None

    def get_lockdown_client(self) -> LockdownClient:
        return create_using_usbmux(serial=self.udid,
                                   usbmux_address=self.usbmux_address)


gcfg: GlobalConfig = GlobalConfig()


def get_udid() -> str:
    if gcfg.udid:
        return gcfg.udid
    raise RuntimeError('udid not set')


@click.group()
@click.option('-u', '--udid', default=None, help='udid of device')
@click.option('usbmux_address', '--usbmux', help=USBMUX_OPTION_HELP)
@click.option('--color/--no-color', default=True)
def cli(udid: str, usbmux_address: str, color: bool):
    gcfg.udid = udid
    gcfg.usbmux_address = usbmux_address
    gcfg.color = color
    

import tidevice3.cli.list as _
import tidevice3.cli.developer as _
import tidevice3.cli.uninstall as _


#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""Created on Fri Jan 05 2024 18:10:01 by codeskyblue
"""
import click
from tidevice3.cli.cli_common import cli, gcfg
from pymobiledevice3.lockdown import usbmux
from pymobiledevice3 import usbmux
from pymobiledevice3.cli.cli_common import USBMUX_OPTION_HELP, print_json
from pymobiledevice3.lockdown import create_using_usbmux
from pymobiledevice3.tcp_forwarder import UsbmuxTcpForwarder


@cli.command()
@click.option('-u', '--usb', is_flag=True, help='show only usb devices')
@click.option('-n', '--network', is_flag=True, help='show only network devices')
def list(usb: bool, network: bool):
    """ list connected devices """
    connected_devices = []
    for device in usbmux.list_devices(usbmux_address=gcfg.usbmux_address):
        udid = device.serial

        if usb and not device.is_usb:
            continue

        if network and not device.is_network:
            continue

        lockdown = create_using_usbmux(udid, autopair=False, connection_type=device.connection_type,
                                       usbmux_address=gcfg.usbmux_address)
        connected_devices.append(lockdown.short_info)

    print_json(connected_devices, colored=gcfg.color)




#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""Created on Fri Jan 05 2024 20:03:54 by codeskyblue
"""

import logging

import click
from tidevice3.cli.cli_common import cli, gcfg
from pymobiledevice3.services.installation_proxy import InstallationProxyService

logger = logging.getLogger(__name__)


@cli.command()
@click.argument('bundle_identifier')
def uninstall(bundle_identifier: str):
    """ Uninstall application """
    service_provider = gcfg.get_lockdown_client()
    InstallationProxyService(lockdown=service_provider).uninstall(bundle_identifier)
    


#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""Created on Fri Jan 05 2024 18:10:01 by codeskyblue
"""
import logging
from tidevice3.cli.cli_common import cli, gcfg
from pymobiledevice3.services.amfi import AmfiService
from pymobiledevice3.services.mobile_image_mounter import auto_mount
from pymobiledevice3.exceptions import AlreadyMountedError

logger = logging.getLogger(__name__)


@cli.command()
def developer():
    """ enable developer mode """
    service_provider = gcfg.get_lockdown_client()
    if not service_provider.developer_mode_status:
        logger.info('enable developer mode')
        AmfiService(service_provider).enable_developer_mode()
    else:
        logger.info('developer mode already enabled')
    
    try:
        auto_mount(service_provider)
        logger.info('mount developer image')
    except AlreadyMountedError:
        logger.info('developer image already mounted')
    


#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""Created on Fri Jan 05 2024 17:47:29 by codeskyblue
"""
import logging
import sys

import click

from tidevice3.cli.cli_common import cli

logger = logging.getLogger(__name__)


def main():
    try:
        cli(auto_envvar_prefix='TIDEVICE3')
    except Exception as e:
        click.echo(f"Error: {type(e)} {e}")
        sys.exit(1)


if __name__ == '__main__':
    main()